@@ -1,32 +1,22 @@
-import json
 from abc import ABC
-from io import TextIOWrapper
 from typing import Any, Dict, List
 
 from geofiles.conversion.static import get_wgs_84
 from geofiles.domain.geo_object_file import GeoObjectFile
 from geofiles.writer.base import BaseWriter
+from geofiles.writer.json_writer import JsonWriter
 
 
-class GeoJsonWriter(BaseWriter, ABC):
+class GeoJsonWriter(JsonWriter, BaseWriter, ABC):
     """
     Writer implementation for creating GeoJSON geometry files
     """
 
-    def _write(
+    def create_json(
         self,
-        file: TextIOWrapper,
         data: GeoObjectFile,
-        write_binary: bool,
-        random_seed: Any,
-    ) -> None:
-        """
-        Write implementation
-        :param file: target to be written
-        :param data: content to be written
-        :param write_binary: flag if file is a binary file
-        :return:
-        """
+        random_seed: Any = None,
+    ) -> Dict[Any, Any]:
         if data.crs != get_wgs_84():
             raise Exception("GeoJSON (RFC 7946) requires WGS:84 coordinate system")
 
@@ -40,6 +30,14 @@ class GeoJsonWriter(BaseWriter, ABC):
         features: List[Any] = []
         res["features"] = features
         for obj in data.objects:
+            if (
+                obj.contains_scaling()
+                or obj.contains_rotation()
+                or obj.contains_translation()
+            ):
+                raise Exception(
+                    "GeoJSON does not support local object transformation information"
+                )
             polygon: Dict[Any, Any] = dict()
             polygon["type"] = "MultiPolygon"
             coordinates: List[Any] = []
@@ -53,7 +51,7 @@ class GeoJsonWriter(BaseWriter, ABC):
                 coordinates.append([f])
             features.append(polygon)
 
-        json.dump(res, file)
+        return res
 
     def get_file_type(self) -> str:
         """
