@@ -1,37 +1,23 @@
 import xml.etree.ElementTree as ET
 from abc import ABC
-from io import TextIOWrapper
 from typing import Any
 
 from geofiles.conversion.static import get_wgs_84
 from geofiles.domain.geo_object_file import GeoObjectFile
 from geofiles.writer.base import BaseWriter
+from geofiles.writer.xml_writer import XmlWriter
 
 
-class KmlWriter(BaseWriter, ABC):
+class KmlWriter(XmlWriter, BaseWriter, ABC):
     """
     Writer implementation for creating KML geometry files
     """
 
-    def _write(
-        self,
-        file: TextIOWrapper,
-        data: GeoObjectFile,
-        write_binary: bool,
-        random_seed: Any,
-    ) -> None:
-        """
-        Write implementation
-        :param file: target to be written
-        :param data: content to be written
-        :param write_binary: flag if file is a binary file
-        :return:
-        """
+    def create_xml(
+        self, data: GeoObjectFile, random_seed: Any = None
+    ) -> ET.ElementTree:
         self._contains_transformation_information(data)
 
-        if "b" not in file.mode.lower():
-            raise Exception("File must be opened in binary mode for KML")
-
         if data.crs != get_wgs_84():
             raise Exception("Kml requires WGS:84 coordinate system")
 
@@ -41,6 +27,14 @@ class KmlWriter(BaseWriter, ABC):
         root = ET.Element("kml")
         root.attrib["xmlns"] = "http://www.opengis.net/kml/2.2"
         for obj in data.objects:
+            if (
+                obj.contains_scaling()
+                or obj.contains_rotation()
+                or obj.contains_translation()
+            ):
+                raise Exception(
+                    "KML does not support local object transformation information"
+                )
             placemark = ET.Element("Placemark")
             root.append(placemark)
             name = ET.Element("name")
@@ -72,8 +66,7 @@ class KmlWriter(BaseWriter, ABC):
                 for coord in coords:
                     coordinates.text += str(coord) + " "
 
-        tree = ET.ElementTree(root)
-        tree.write(file, encoding="ascii", xml_declaration=True)
+        return ET.ElementTree(root)
 
     def get_file_type(self) -> str:
         """
